api.users.v1.subject — Argus-Toolbelt 1.0 documentation

# Source code for api.users.v1.subject

    """Autogenerated API"""
    import requests
    from argus_cli.plugin import register_command

    @register_command(extending=('users','v1','subject'))
    def list_subjects(subjectID: list = None, offset: int = None, limit: int = 25,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Get user or group profiles (PUBLIC)

        :param list subjectID: IDs of subjects
        :param int offset: Offset results
        :param int limit: Limit results
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :returns: {"offset": 570, "limit": 125, "responseCode": 200, "count": 64, "data": [{"id": 627, "customerID": 614, "name": "Donna Rodriguez"}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Cultural view American talk.", "messageTemplate": "Ball itself against other culture.", "field": "Open reality billion.", "parameter": {}, "timestamp": 1260389241}], "currentPage": 257, "size": 592}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/users/v1/subject".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if limit:
            body.update({"limit": limit})

        if subjectID:
            body.update({"subjectID": subjectID})

        if offset:
            body.update({"offset": offset})

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('users','v1','subject'))
    def find_subjects(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, domain: list = None, type: str = None, subjectID: list = None, excludeSubjectID: list = None, parentID: list = None, ancestorID: list = None, get_aclAncestorID: list = None, get_aclCustomerID: list = None, excludeAncestorID: list = None, userName: list = None, email: list = None, mobile: list = None, searchString: str = None, languageID: list = None, requiredFunctionID: list = None, requiredFunctionCustomerID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', requireAllFunctions: bool = 'False',json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Search user or group profiles (PUBLIC)

        :param int limit: Set this value to set max number of results. By default, no restriction on result set size.
        :param int offset: Set this value to skip the first (offset) objects. By default, return result from first object.
        :param int includeFlags: Only include objects which have includeFlags set.
        :param int excludeFlags: Exclude objects which have excludeFlags set.
        :param list subCriteria:
        :param list customerID: Restrict search to data belonging to specified customers.
        :param list domain:
        :param str type:
        :param list subjectID:
        :param list excludeSubjectID:
        :param list parentID:
        :param list ancestorID:
        :param list get_aclAncestorID:
        :param list get_aclCustomerID:
        :param list excludeAncestorID:
        :param list userName:
        :param list email:
        :param list mobile:
        :param str searchString:
        :param list languageID:
        :param list requiredFunctionID:
        :param int requiredFunctionCustomerID:
        :param bool includeDeleted: Set to true to include deleted objects. By default, exclude deleted objects.
        :param bool exclude: Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded.
        :param bool required: Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
        :param bool requireAllFunctions:
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :returns: {"offset": 604, "limit": 228, "responseCode": 200, "count": 426, "data": [{"id": 234, "customerID": 502, "name": "Manuel Edwards"}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Here director stop focus heavy participant.", "messageTemplate": "Prepare turn before ahead national research performance why.", "field": "Market owner difficult page degree new daughter.", "parameter": {}, "timestamp": 1308380633}], "currentPage": 280, "size": 281}
        """
        from requests import post
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/users/v1/subject/search".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if limit:
            body.update({"limit": limit})

        if offset:
            body.update({"offset": offset})

        if includeDeleted:
            body.update({"includeDeleted": includeDeleted})

        if includeFlags:
            body.update({"includeFlags": includeFlags})

        if excludeFlags:
            body.update({"excludeFlags": excludeFlags})

        if subCriteria:
            body.update({"subCriteria": subCriteria})

        if exclude:
            body.update({"exclude": exclude})

        if required:
            body.update({"required": required})

        if customerID:
            body.update({"customerID": customerID})

        if domain:
            body.update({"domain": domain})

        if type:
            body.update({"type": type})

        if subjectID:
            body.update({"subjectID": subjectID})

        if excludeSubjectID:
            body.update({"excludeSubjectID": excludeSubjectID})

        if parentID:
            body.update({"parentID": parentID})

        if ancestorID:
            body.update({"ancestorID": ancestorID})

        if get_aclAncestorID:
            body.update({"get_aclAncestorID": get_aclAncestorID})

        if get_aclCustomerID:
            body.update({"get_aclCustomerID": get_aclCustomerID})

        if excludeAncestorID:
            body.update({"excludeAncestorID": excludeAncestorID})

        if userName:
            body.update({"userName": userName})

        if email:
            body.update({"email": email})

        if mobile:
            body.update({"mobile": mobile})

        if searchString:
            body.update({"searchString": searchString})

        if languageID:
            body.update({"languageID": languageID})

        if requiredFunctionID:
            body.update({"requiredFunctionID": requiredFunctionID})

        if requiredFunctionCustomerID:
            body.update({"requiredFunctionCustomerID": requiredFunctionCustomerID})

        if requireAllFunctions:
            body.update({"requireAllFunctions": requireAllFunctions})

        response = post(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('users','v1','subject'))
    def get_subject_by_id(subjectID: int,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Get user or group profile by ID (PUBLIC)

        :param int subjectID: ID of subject
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises ObjectNotFoundException: on 404
        :returns: {"offset": 936, "limit": 568, "responseCode": 200, "count": 939, "metaData": {"additionalProperties": {}}, "messages": [{"message": "Seven production character occur effect.", "messageTemplate": "Create idea management mention.", "field": "Type shake possible not.", "parameter": {}, "timestamp": 1218257500}], "currentPage": 952, "size": 593}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/users/v1/subject/{subjectID}".format(subjectID=subjectID)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('users','v1','subject'))
    def get_subject_by_name(subjectName: str,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Get user or group profile by name (PUBLIC)

        :param str subjectName: Username or group shortname
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises ObjectNotFoundException: on 404
        :returns: {"offset": 342, "limit": 308, "responseCode": 200, "count": 160, "metaData": {"additionalProperties": {}}, "messages": [{"message": "Better I future central vote discussion behind government.", "messageTemplate": "Lot free nearly oil near campaign maybe.", "field": "Country down issue view environment against.", "parameter": {}, "timestamp": 1003676805}], "currentPage": 571, "size": 869}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/users/v1/subject/{subjectName}".format(subjectName=subjectName)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response